@@ -997,6 +997,8 @@ class Unet(nn.Module):
 
         # guide researchers
 
+        assert attn_heads > 1, 'you need to have more than 1 attention head, ideally at least 4 or 8'
+
         if dim < 128:
             print('The base dimension of your u-net should ideally be no smaller than 128, as recommended by a professional DDPM trainer https://nonint.com/2022/05/04/friends-dont-let-friends-train-small-diffusion-models/')
 
@@ -1089,7 +1091,6 @@ class Unet(nn.Module):
         # normalizations
 
         self.norm_cond = nn.LayerNorm(cond_dim)
-        self.norm_mid_cond = nn.LayerNorm(cond_dim)
 
         # text encoding conditioning (optional)
 
@@ -1423,7 +1424,7 @@ class Unet(nn.Module):
             x = torch.cat((x, init_conv_residual), dim = 1)
 
         if exists(self.final_res_block):
-            x = self.final_res_block(x, t)
+            x = self.final_res_block(x, None, t)
 
         return self.final_conv(x)
 
